@@ -389,6 +389,31 @@ ldns_status ldns_dnssec_verify_denial_nsec3(ldns_rr *rr,
 								    ldns_rr_type packet_qtype,
 								    bool packet_nodata);
 
+/**
+ * Same as ldns_status ldns_dnssec_verify_denial_nsec3 but also returns
+ * the nsec rr that matched.
+ *
+ * \param[in] rr The (query) RR to check the denial of existence for
+ * \param[in] nsecs The list of NSEC3 RRs that are supposed to deny the
+ *                  existence of the RR
+ * \param[in] rrsigs The RRSIG rr covering the NSEC RRs
+ * \param[in] packet_rcode The RCODE value of the packet that provided the
+ *                         NSEC3 RRs
+ * \param[in] packet_qtype The original query RR type
+ * \param[in] packet_nodata True if the providing packet had an empty ANSWER
+ *                          section
+ * \param[in] match On match, the given (reference to a) pointer will be set 
+ *                  to point to the matching nsec resource record.
+ * \return LDNS_STATUS_OK if the NSEC3 RRs deny the existence, error code
+ *                        containing the reason they do not otherwise
+ */
+ldns_status ldns_dnssec_verify_denial_nsec3_match(ldns_rr *rr,
+						  ldns_rr_list *nsecs,
+						  ldns_rr_list *rrsigs,
+						  ldns_pkt_rcode packet_rcode,
+						  ldns_rr_type packet_qtype,
+						  bool packet_nodata,
+						  ldns_rr **match);
 /**
  * Verifies the already processed data in the buffers
  * This function should probably not be used directly.
@@ -465,6 +490,7 @@ ldns_status ldns_verify_rrsig(ldns_rr_list *rrset,
 						ldns_rr *rrsig,
 						ldns_rr *key);
 
+#if LDNS_BUILD_CONFIG_HAVE_SSL
 /**
  * verifies a buffer with signature data for a buffer with rrset data 
  * with an EVP_PKEY
@@ -474,12 +500,10 @@ ldns_status ldns_verify_rrsig(ldns_rr_list *rrset,
  * \param[in] key the EVP key structure
  * \param[in] digest_type The digest type of the signature
  */
-#ifdef HAVE_SSL
 ldns_status ldns_verify_rrsig_evp(ldns_buffer *sig,
 						    ldns_buffer *rrset,
 						    EVP_PKEY *key,
 						    const EVP_MD *digest_type);
-#endif
 
 /**
  * Like ldns_verify_rrsig_evp, but uses raw signature data.
@@ -489,7 +513,6 @@ ldns_status ldns_verify_rrsig_evp(ldns_buffer *sig,
  * \param[in] key the EVP key structure
  * \param[in] digest_type The digest type of the signature
  */
-#ifdef HAVE_SSL
 ldns_status ldns_verify_rrsig_evp_raw(unsigned char *sig,
 							   size_t siglen,
 							   ldns_buffer *rrset,
