@@ -27,8 +27,8 @@ extern "C" {
 #define dprintf(X,Y) fprintf(stderr, (X), (Y))
 /* #define	dprintf(X, Y)  */
 
-#define LDNS_VERSION "1.6.7"
-#define LDNS_REVISION ((1<<16)|(6<<8)|(7))
+#define LDNS_VERSION "1.6.10"
+#define LDNS_REVISION ((1<<16)|(6<<8)|(10))
 
 /**
  * splint static inline workaround
@@ -50,6 +50,8 @@ extern "C" {
 
 #define LDNS_XMALLOC(type, count)	((type *) malloc((count) * sizeof(type)))
 
+#define LDNS_CALLOC(type, count)	((type *) calloc((count), sizeof(type)))
+
 #define LDNS_REALLOC(ptr, type)		LDNS_XREALLOC((ptr), type, 1)
 
 #define LDNS_XREALLOC(ptr, type, count)				\
@@ -268,6 +270,22 @@ const char * ldns_version(void);
  */
 time_t mktime_from_utc(const struct tm *tm);
 
+/**
+ * The function interprets time as the number of seconds since epoch
+ * with respect to now using serial arithmitics (rfc1982).
+ * That number of seconds is then converted to broken-out time information.
+ * This is especially usefull when converting the inception and expiration
+ * fields of RRSIG records.
+ *
+ * \param[in] time number of seconds since epoch (midnight, January 1st, 1970)
+ *            to be intepreted as a serial arithmitics number relative to now.
+ * \param[in] now number of seconds since epoch (midnight, January 1st, 1970)
+ *            to which the time value is compared to determine the final value.
+ * \param[out] result the struct with the broken-out time information
+ * \return result on success or NULL on error
+ */
+struct tm * ldns_serial_arithmitics_gmtime_r(int32_t time, time_t now, struct tm *result);
+ 
 /**
  * Seed the random function.
  * If the file descriptor is specified, the random generator is seeded with
